# Symbol-sdk-core-python

[![Build Status](https://travis-ci.com/nemtech/symbol-sdk-core-python.svg?branch=main)](https://travis-ci.com/nemtech/symbol-sdk-core-python)
[![PyPI version](https://img.shields.io/pypi/v/symbol-sdk-core-python.svg)](https://pypi.python.org/pypi/symbol-sdk-core-python/)

This is symbol project core sdk python library.
